import _capitalize from 'lodash/capitalize';
import _mapKeys from 'lodash/mapKeys';
import _assign from 'lodash/assign';
import React from 'react';
import Create from './blueprints/Create';
import Update from './blueprints/Update';
import Destroy from './blueprints/Destroy';


function getCreateDialog(defaults) {
  return function (props, options) {
    var params = _assign(defaults, options);
    return React.createElement(Create(params), props);
  };
}

function getUpdateDialog(defaults) {
  return function (props, options) {
    var params = _assign(defaults, options);
    return React.createElement(Update(params), props);
  };
}

function getDestroyDialog(defaults) {
  return function (props, options) {
    var params = _assign(defaults, options);
    return React.createElement(Destroy(params), props);
  };
}

export default {

  dependencies: ['models'],

  load: function load(lore) {
    var schemas = lore.loader.loadModels();

    lore.dialogs = {};

    _mapKeys(schemas, function (schema, modelName) {
      lore.dialogs[modelName] = lore.dialogs[modelName] || {};

      lore.dialogs[modelName].create = getCreateDialog({
        modelName: modelName,
        attributes: schema.attributes,
        title: 'Create ' + _capitalize(modelName),
        cancelButtonText: 'Cancel',
        submitButtonText: 'Create',
        defaults: {}
      });

      lore.dialogs[modelName].update = getUpdateDialog({
        modelName: modelName,
        attributes: schema.attributes,
        title: 'Update ' + _capitalize(modelName),
        cancelButtonText: 'Cancel',
        submitButtonText: 'Update',
        defaults: {}
      });

      lore.dialogs[modelName].destroy = getDestroyDialog({
        modelName: modelName,
        attributes: schema.attributes,
        title: 'Delete ' + _capitalize(modelName),
        cancelButtonText: 'Cancel',
        submitButtonText: 'Delete',
        defaults: {}
      });
    });
  }

};